# This file is automatically generated by generate.py using api.json

class _Teams:
    def __init__(self, client=None):
        self.client = client

    def find_by_organization(self, organization_id, params={}, **options):
        """Finds all teams that the user has access to."""
        path = '/organizations/%d/teams' % (organization_id)
        return self.client.get_collection(path, params, **options)
